@@ -20,7 +20,7 @@ logging=logger.get_logger(name='mlops_cdf')
 global_client = {}
 api_keys=config.api_keys
 
-env_vars = {k.upper():str(v) for k,v in config.envs_dir.items() if v}
+env_vars = {k.upper():str(v) for k,v in config.envs_dic.items() if v}
 env_vars.update({'PLATFORM':'cdf'})
 try:
     env_vars.pop('GOOGLE_PROJECT_ID')
@@ -268,12 +268,12 @@ def upload_folder(
     
     Params:
         - external_id: external id (should be unique in the CDF project)
-        - path: path of local folder where content is stored
+        - path: (Path) path of local folder where content is stored
         - metadata: dictionary with file metadata
         - target_folder: path where compressed file should be stored
         - overwrite: if overwrite==False and `external_id` exists => exception
     """
-    base_name = os.path.join(path, 'archive')
+    base_name = path / 'archive'
     archive_name = make_archive(base_name, 'gztar', path)
     file_info = upload_file(
         external_id, 
@@ -295,11 +295,11 @@ def download_folder(external_id, path):
 
     Params:
     - external_id: external id
-    - path: path of local folder where content will be stored
+    - path: (Path) path of local folder where content will be stored
     """
-    base_name = os.path.join(path, 'archive.tar.gz')
+    base_name = path / 'archive.tar.gz'
     download_file(dict(external_id=external_id), base_name)
-    unpack_archive(base_name, os.path.dirname(base_name))
+    unpack_archive(base_name, base_name.parent)
     os.remove(base_name)
     logging.info(f"Model file/s downloaded to {path}")
 
