@@ -10,7 +10,7 @@ import akerbp.mlops.model_manager as mm
 from akerbp.mlops import __version__ as version
 from akerbp.mlops.core import config, logger 
 logging=logger.get_logger("mlops_services")
-c = config.read_config()
+c = config.read_service_settings()
 env = config.envs.env
 
 model_module = import_module(c.model_import_path)
